@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 # Version.
-our $VERSION = 0.08;
+our $VERSION = 0.09;
 
 1;
 
@@ -27,6 +27,10 @@ Task::PYX - Install the PYX modules.
 
 =over
 
+=item L<App::PYX2XML>
+
+Perl class for pyx2xml application.
+
 =item L<PYX>
 
 A perl module for PYX handling.
@@ -47,6 +51,10 @@ PYX parser.
 
 Processing PYX data or file and write as SGML.
 
+=item L<PYX::SGML::Tags>
+
+Processing PYX data or file and write as SGML via Tags.
+
 =item L<PYX::Sort>
 
 Processing PYX data or file and sort element attributes.
@@ -93,12 +101,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2015 Michal Špaček
+ © 2015-2016 Michal Špaček
  Artistic License
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.08
+0.09
 
 =cut
